use serde::Deserialize;
use std::fmt::Debug;

#[derive(Clone, Deserialize)]
pub struct SMTPConfig {
    mail: String,
    secret: String,
    provider: String,
}

impl SMTPConfig {
    pub fn new<T: AsRef<str>>(mail: T, secret: T, provider: T) -> Self {
        Self {
            mail: mail.as_ref().to_owned(),
            secret: secret.as_ref().to_owned(),
            provider: provider.as_ref().to_owned(),
        }
    }

    #[must_use]
    pub fn mail(&self) -> &str {
        &self.mail
    }

    #[must_use]
    pub fn secret(&self) -> &str {
        &self.secret
    }

    #[must_use]
    pub fn provider(&self) -> &str {
        &self.provider
    }
}

impl Debug for SMTPConfig {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        f.debug_struct("SMTPConfig")
            .field("mail", &self.mail)
            .field("provider", &self.provider)
            .field("secret", &"<reducted>")
            .finish()
    }
}
